@@ -140,7 +140,11 @@ def check_sites_integrity(molecules, chains_res, useTMPpdb=False):
 
         res_tits = True
         if ter:
-            res_tits = bool(prev_resname in TITRABLERESIDUES)
+            if (not Config.pypka_params['ser_thr_titration'] and 
+                prev_resname in ('SER', 'THR')):
+                res_tits = False
+            else:
+                res_tits = bool(prev_resname in TITRABLERESIDUES)
 
         res_atoms = copy(cur_atoms)
         (integrity_terminal,
@@ -379,10 +383,12 @@ def make_delphi_inputfile(f_in, f_out, molecules):
         return max_x, max_y, max_z
 
     def correct_termini(resnumb, resname, aname, ntr_res, ctr_res):
-        if resnumb == ntr_res and aname in Config.pypka_params['NTR_atoms']:
+        if resnumb == ntr_res and \
+           aname in Config.pypka_params['NTR_atoms']:
             resname = 'NTR'
             resnumb += TERMINAL_OFFSET
-        elif resnumb == ctr_res and aname in Config.pypka_params['CTR_atoms']:
+        elif resnumb == ctr_res and \
+             aname in Config.pypka_params['CTR_atoms']:
             resname = 'CTR'
             resnumb += TERMINAL_OFFSET
             if aname == 'C':
