@@ -91,10 +91,10 @@ def inputPDBCheck(filename, sites, clean_pdb):
                    str(resnumb) in sites[chain]:
                     chains_res[chain][resnumb] = resname
 
-    if filetype == 'pdb' and not clean_pdb:
-        new_gro_header += '{0}\n'.format(atom_number)
-        with open('TMP.gro', 'w') as f:
-            f.write(new_gro_header + new_gro_body + new_gro_footer)
+    #if filetype == 'pdb' and not clean_pdb:
+    #    new_gro_header += '{0}\n'.format(atom_number)
+    #    with open('TMP.gro', 'w') as f:
+    #        f.write(new_gro_header + new_gro_body + new_gro_footer)
 
     chains_length[last_chain] = chain_length
     #chains_res[chain] = done[chain]
@@ -204,7 +204,9 @@ def cleanPDB(molecules, chains_res, inputpqr, outputpqr):
                     if resnumb in (NTR_numb, CTR_numb):
                         termini_trigger = True
 
-                if aname in ('O1', 'O2', 'H1', 'H2', 'H3') and \
+                if aname in ('O1', 'O2',
+                             'OT1', 'OT2',
+                             'H1', 'H2', 'H3') and \
                    not termini_trigger and resname in PROTEIN_RESIDUES:
                     if aname == 'O1':
                         aname = 'O'
@@ -220,7 +222,9 @@ def cleanPDB(molecules, chains_res, inputpqr, outputpqr):
                                         resnumb, x, y, z, charge, radius, chain=original_chain)
                 if chain in molecules:
                     new_pdb_text += new_line
-                elif aname not in ('H1', 'H2', 'H3', 'O1', 'O2'):
+                elif aname not in ('O1', 'O2',
+                                   'OT1', 'OT2',
+                                   'H1', 'H2', 'H3'):
                     if resname in ('SER', 'THR') and aname == 'HG1':
                         aname = 'HG'
                     removed_pdb_lines.append(new_line)
@@ -373,7 +377,7 @@ def add_non_protein(pdbfile_origin, add_to_pdb, keep_membrane=False, keep_ions=F
                         new_file_body += new_pdb_line(last_anumb, aname, resname,
                                                       resnumb, x, y, z, chain=chain)
 
-                    if resname in list(LIPIDS.values()):
+                    if resname in list(Config.pypka_params.LIPIDS.values()):
                         aname, resname, to_include = convert_FF_atomnames(aname, resname)
                         if to_include:
                             last_anumb += 1
@@ -390,8 +394,8 @@ def add_non_protein(pdbfile_origin, add_to_pdb, keep_membrane=False, keep_ions=F
         f_new.write(new_file_body)
 
 def convert_FF_atomnames(aname, resname):
-    popc_resname = config.lipids['POPC']
-    chol_resname = config.lipids['cholesterol']
+    popc_resname = Config.pypka_params.LIPIDS['POPC']
+    chol_resname = Config.pypka_params.LIPIDS['cholesterol']
 
     lookup = [((' N  ', popc_resname), ('NTM', 'CHL')),
               ((' C12', popc_resname), ('CB ', 'CHL')),
